# coding=utf-8
from otlmow_model.Classes.Onderdeel.OpgaandeHoutigeVegetatie import OpgaandeHoutigeVegetatie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Iepenstruweel(OpgaandeHoutigeVegetatie):
    """H2 - Houtige begroeiing in holle wegen van de leemstreek met gladde iep, ruwe iep, meidoorn spp., gewone es, gewone vlier, maarts viooltje, vogelmelk, aalbes, gevlekte aronskelk, speenkruid, vingerhelmbloem, grote keverorchis, klimop, klimopereprijs, look-zonder-look."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Iepenstruweel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
