# coding=utf-8
from otlmow_model.Classes.Onderdeel.Ruigte import Ruigte


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brandnetelruigte(Ruigte):
    """R3 - dominante bedekking van grote brandnetel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandnetelruigte'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
