# coding=utf-8
from otlmow_model.Classes.Onderdeel.BloemrijkGraslandGraslandfase4 import BloemrijkGraslandGraslandfase4


# Generated with OTLClassCreator. To modify: extend, do not edit
class BloemrijkGlanshavergrasland(BloemrijkGraslandGraslandfase4):
    """G4a - aardaker, beemdkroon, beemdooievaarsbek,
bevertjes, gele morgenster, gewone agrimonie,
gewone rolklaver, gewone vogelmelk, glad
walstro, goudhaver, graslathyrus, groot
streepzaad, grote bevernel, grote pimpernel,
gulden boterbloem, gulden sleutelbloem,
klavervreter, kleine bevernel, kleine ratelaar,
knolboterbloem, knolsteenbreek, knoopkruid,
kraailook, margriet, muskuskaasjeskruid,
naakte lathyrus, rapunzelklokje, ruige
leeuwentand, veldlathyrus, veldsalie, vijfdelig
kaasjeskruid en zachte haver, grote ratelaar,
vertakte leeuwentand, vierzadige wikke."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BloemrijkGlanshavergrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
