# coding=utf-8
from otlmow_model.Classes.Onderdeel.BloemrijkGraslandGraslandfase4 import BloemrijkGraslandGraslandfase4


# Generated with OTLClassCreator. To modify: extend, do not edit
class KalkrijkKamgrasland(BloemrijkGraslandGraslandfase4):
    """G4c - aarddistel, beemdkroon, bevertjes, driedistel,
duifkruid, geelhartje, gevinde kortsteel,
gewone agrimonie, goudhaver, grote tijm,
gulden sleutelbloem, kattendoorn, kleine
bevernel, kleine pimpernel, knolboterbloem,
kruipend stalkruid, ruige leeuwentand, ruige
weegbree, voorjaarszegge, wilde marjolein,
zachte haver, zeegroene zegge."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KalkrijkKamgrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
